==> grommet-1.1.0.jar: META-INF/resources/webjars/grommet/1.1.0/README.md <==
# Grommet: The most advanced UX framework for enterprise apps

[![Slack](http://alansouzati.github.io/artic/img/slack-badge.svg)](http://slackin.grommet.io)  [![Build Status](https://api.travis-ci.org/grommet/grommet.svg)](https://travis-ci.org/grommet/grommet)  [![Coverage Status](https://coveralls.io/repos/github/grommet/grommet/badge.svg?branch=master)](https://coveralls.io/github/grommet/grommet?branch=master) [![Code Climate](https://codeclimate.com/github/grommet/grommet/badges/gpa.svg)](https://codeclimate.com/github/grommet/grommet)  [![Dependency Status](https://david-dm.org/grommet/grommet.svg)](https://david-dm.org/grommet/grommet)  [![devDependency Status](https://david-dm.org/grommet/grommet/dev-status.svg)](https://david-dm.org/grommet/grommet#info=devDependencies)  [![CDNJS](https://img.shields.io/cdnjs/v/grommet.svg)](https://cdnjs.com/libraries/grommet)

<img align="right" height="260" src="https://grommet.github.io/img/grommet.svg">

### Documentation

Visit the [grommet.github.io](https://grommet.github.io/) website for more information.

### Support / Contributing

Before opening an issue or pull request, please read the [Contributing](https://github.com/grommet/grommet/blob/master/CONTRIBUTING.md) guide.

### Hello World

  The quickest way to get started is to access the [Hello World](https://grommet.github.io/docs/hello-world) page.

### Install

  You can install Grommet using either of the methods below.

  For Bower users:
  ```
    $ bower install grommet
  ```

  For NPM users:
  ```
    $ npm install -g grommet
  ```

  Detailed instructions are on the [Get Started](https://grommet.github.io/docs/get-started) page.

### Build

  Refer to the [Grommet Build Wiki](https://github.com/grommet/grommet/wiki/Building-Grommet) for instructions on how to install your local copy of Grommet.

### Release History

  See the [Change Log](https://github.com/grommet/grommet/wiki/Change-Log).

### Tools Behind Grommet

 Grommet is produced using these great tools
 * [Travis CI](https://travis-ci.org/grommet/grommet) for continuous integration
 * [Sauce Labs](https://saucelabs.com/) for automated browser testing
 * [BrowserStack](https://www.browserstack.com) for manual browser testing
 * [Waffle.io](https://waffle.io/grommet/grommet) for backlog tracking

==> grommet-1.2.1.jar: META-INF/resources/webjars/grommet/1.2.1/README.md <==
# Grommet: The most advanced UX framework for enterprise apps

**Note**: This is the Bower distribution of [Grommet](https://github.com/grommet/grommet).

[![Slack](http://alansouzati.github.io/artic/img/slack-badge.svg)](http://slackin.grommet.io)  [![Build Status](https://api.travis-ci.org/grommet/grommet.svg)](https://travis-ci.org/grommet/grommet)  [![Coverage Status](https://coveralls.io/repos/grommet/grommet/badge.svg)](https://coveralls.io/r/grommet/grommet) [![Code Climate](https://codeclimate.com/github/grommet/grommet/badges/gpa.svg)](https://codeclimate.com/github/grommet/grommet)  [![Dependency Status](https://david-dm.org/grommet/grommet.svg)](https://david-dm.org/grommet/grommet)  [![devDependency Status](https://david-dm.org/grommet/grommet/dev-status.svg)](https://david-dm.org/grommet/grommet#info=devDependencies)

<img align="right" height="260" src="https://grommet.github.io/img/grommet.svg">

### Documentation

Visit the [grommet.github.io](https://grommet.github.io/) website for more information.

### Support / Contributing

Before opening an issue or pull request, please read the [Contributing](https://github.com/grommet/grommet/blob/master/CONTRIBUTING.md) guide.

### Hello World

  The quickest way to get started is to access the [Hello World](https://grommet.github.io/docs/hello-world) page.

### Install

  You can install Grommet using either of the methods below.

  For Bower users:
  ```
    $ bower install grommet
  ```

  For NPM users:
  ```
    $ npm install -g grommet
  ```

  Detailed instructions are on the [Get Started](https://grommet.github.io/docs/get-started) page.

### Build

  Refer to the [Grommet Build Wiki](https://github.com/grommet/grommet/wiki/Building-Grommet) for instructions on how to install your local copy of Grommet.

### Release History

  See the [Change Log](https://github.com/grommet/grommet/wiki/Change-Log).

### Tools Behind Grommet

 Grommet is produced using these great tools
 * [Travis CI](https://travis-ci.org/grommet/grommet) for continuous integration
 * [Sauce Labs](https://saucelabs.com/) for automated browser testing
 * [BrowserStack](https://www.browserstack.com) for manual browser testing
 * [Waffle.io](https://waffle.io/grommet/grommet) for backlog tracking
